@@ -10,7 +10,7 @@ def test_after(py_and_json: PyAndJson):
         return input_value + f'| context: {info.context}'
 
     v = py_and_json(
-        {'type': 'function', 'mode': 'after', 'function': {'type': 'general', 'function': f}, 'schema': {'type': 'str'}}
+        {'type': 'function-after', 'function': {'type': 'general', 'function': f}, 'schema': {'type': 'str'}}
     )
 
     assert v.validate_test('foobar') == 'foobar| context: None'
@@ -24,12 +24,7 @@ def test_mutable_context(py_and_json: PyAndJson):
         return input_value
 
     v = py_and_json(
-        {
-            'type': 'function',
-            'mode': 'before',
-            'function': {'type': 'general', 'function': f},
-            'schema': {'type': 'str'},
-        }
+        {'type': 'function-before', 'function': {'type': 'general', 'function': f}, 'schema': {'type': 'str'}}
     )
     mutable_context = {}
     assert v.validate_test('foobar', None, mutable_context) == 'foobar'
@@ -49,12 +44,8 @@ def test_typed_dict(py_and_json: PyAndJson):
         {
             'type': 'typed-dict',
             'fields': {
-                'f1': {
-                    'schema': {'type': 'function', 'mode': 'plain', 'function': {'type': 'general', 'function': f1}}
-                },
-                'f2': {
-                    'schema': {'type': 'function', 'mode': 'plain', 'function': {'type': 'general', 'function': f2}}
-                },
+                'f1': {'schema': {'type': 'function-plain', 'function': {'type': 'general', 'function': f1}}},
+                'f2': {'schema': {'type': 'function-plain', 'function': {'type': 'general', 'function': f2}}},
             },
         }
     )
@@ -70,7 +61,7 @@ def test_wrap(py_and_json: PyAndJson):
         return validator(input_value) + f'| context: {info.context}'
 
     v = py_and_json(
-        {'type': 'function', 'mode': 'wrap', 'function': {'type': 'general', 'function': f}, 'schema': {'type': 'str'}}
+        {'type': 'function-wrap', 'function': {'type': 'general', 'function': f}, 'schema': {'type': 'str'}}
     )
 
     assert v.validate_test('foobar') == 'foobar| context: None'
@@ -85,7 +76,7 @@ def test_isinstance(py_and_json: PyAndJson):
         return validator(input_value)
 
     v = py_and_json(
-        {'type': 'function', 'mode': 'wrap', 'function': {'type': 'general', 'function': f}, 'schema': {'type': 'str'}}
+        {'type': 'function-wrap', 'function': {'type': 'general', 'function': f}, 'schema': {'type': 'str'}}
     )
 
     assert v.validate_python('foobar', None, {}) == 'foobar'
@@ -121,12 +112,8 @@ def test_validate_assignment_with_context():
         {
             'type': 'typed-dict',
             'fields': {
-                'f1': {
-                    'schema': {'type': 'function', 'mode': 'plain', 'function': {'type': 'general', 'function': f1}}
-                },
-                'f2': {
-                    'schema': {'type': 'function', 'mode': 'plain', 'function': {'type': 'general', 'function': f2}}
-                },
+                'f1': {'schema': {'type': 'function-plain', 'function': {'type': 'general', 'function': f1}}},
+                'f2': {'schema': {'type': 'function-plain', 'function': {'type': 'general', 'function': f2}}},
             },
         }
     )
